{
    "$graph": [
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "types": [
                        {
                            "type": "enum",
                            "name": "#biom-convert-table.yaml/table_type",
                            "label": "The type of the table to produce",
                            "symbols": [
                                "#biom-convert-table.yaml/table_type/OTU table",
                                "#biom-convert-table.yaml/table_type/Pathway table",
                                "#biom-convert-table.yaml/table_type/Function table",
                                "#biom-convert-table.yaml/table_type/Ortholog table",
                                "#biom-convert-table.yaml/table_type/Gene table",
                                "#biom-convert-table.yaml/table_type/Metabolite table",
                                "#biom-convert-table.yaml/table_type/Taxon table",
                                "#biom-convert-table.yaml/table_type/Table"
                            ]
                        }
                    ],
                    "class": "SchemaDefRequirement"
                }
            ],
            "hints": [
                {
                    "packages": [
                        {
                            "specs": [
                                "https://doi.org/10.1186/2047-217X-1-7"
                            ],
                            "version": [
                                "2.1.6"
                            ],
                            "package": "biom-format"
                        }
                    ],
                    "class": "SoftwareRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_3746",
                    "inputBinding": {
                        "prefix": "--input-fp"
                    },
                    "id": "#biom-convert.cwl/biom"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "label": "Output as HDF5-formatted table.",
                    "inputBinding": {
                        "prefix": "--to-hdf5"
                    },
                    "id": "#biom-convert.cwl/hdf5"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "doc": "The observation metadata to include from the input BIOM table file when\ncreating a tsv table file. By default no observation metadata will be\nincluded.\n",
                    "inputBinding": {
                        "prefix": "--header-key"
                    },
                    "id": "#biom-convert.cwl/header_key"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "label": "Output as JSON-formatted table.",
                    "inputBinding": {
                        "prefix": "--to-json"
                    },
                    "id": "#biom-convert.cwl/json"
                },
                {
                    "type": [
                        "null",
                        "#biom-convert-table.yaml/table_type"
                    ],
                    "inputBinding": {
                        "prefix": "--table-type"
                    },
                    "id": "#biom-convert.cwl/table_type"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "label": "Output as TSV-formatted (classic) table.",
                    "inputBinding": {
                        "prefix": "--to-tsv"
                    },
                    "id": "#biom-convert.cwl/tsv"
                }
            ],
            "baseCommand": [
                "biom",
                "convert"
            ],
            "arguments": [
                {
                    "valueFrom": "result",
                    "prefix": "--output-fp"
                }
            ],
            "id": "#biom-convert.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute",
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "result"
                    },
                    "id": "#biom-convert.cwl/result"
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "types": [
                        {
                            "$import": "#biom-convert-table.yaml/table_type"
                        }
                    ],
                    "class": "SchemaDefRequirement"
                }
            ],
            "hints": [
                {
                    "packages": [
                        {
                            "specs": [
                                "https://doi.org/10.1186/2047-217X-1-7"
                            ],
                            "version": [
                                "2.1.6"
                            ],
                            "package": "biom-format"
                        }
                    ],
                    "class": "SoftwareRequirement"
                }
            ],
            "inputs": [
                {
                    "format": "http://edamontology.org/format_3746",
                    "type": "File",
                    "inputBinding": {
                        "prefix": "--input-fp"
                    },
                    "id": "#biom-summarize_table.cwl/biom"
                }
            ],
            "baseCommand": [
                "biom",
                "summarize-table"
            ],
            "arguments": [
                {
                    "valueFrom": "otu_table_summary.txt",
                    "prefix": "--output-fp"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "otu_table_summary.txt"
                    },
                    "id": "#biom-summarize_table.cwl/otu_table_summary"
                }
            ],
            "id": "#biom-summarize_table.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute"
        },
        {
            "class": "CommandLineTool",
            "inputs": [
                {
                    "type": "File",
                    "id": "#extract_observations.cwl/tsv_otu_table"
                }
            ],
            "baseCommand": [
                "awk",
                "/#/ {next};{print $1}"
            ],
            "stdin": "$(inputs.tsv_otu_table.path)",
            "stdout": "observations",
            "outputs": [
                {
                    "type": "File",
                    "id": "#extract_observations.cwl/observations",
                    "outputBinding": {
                        "glob": "observations"
                    }
                }
            ],
            "id": "#extract_observations.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute"
        },
        {
            "class": "CommandLineTool",
            "hints": [
                {
                    "packages": [
                        {
                            "specs": [
                                "https://identifiers.org/rrid/RRID:SCR_008249"
                            ],
                            "version": [
                                "1.9.1"
                            ],
                            "package": "qiime"
                        }
                    ],
                    "class": "SoftwareRequirement"
                }
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "doc": "A list of tips (one tip per line) or sequence identifiers (tab-delimited\nlines with a seq identifier in the first field) which should be retained \n",
                    "inputBinding": {
                        "prefix": "--tips_fp=",
                        "separate": false
                    },
                    "id": "#qiime-filter_tree.cwl/tips_or_seqids_to_retain"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "--input_tree_filepath=",
                        "separate": false
                    },
                    "id": "#qiime-filter_tree.cwl/tree"
                }
            ],
            "baseCommand": "filter_tree.py",
            "arguments": [
                {
                    "valueFrom": "pruned.tree",
                    "prefix": "--output_tree_filepath=",
                    "separate": false
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "pruned.tree"
                    },
                    "id": "#qiime-filter_tree.cwl/pruned_tree"
                }
            ],
            "id": "#qiime-filter_tree.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute"
        },
        {
            "class": "CommandLineTool",
            "hints": [
                {
                    "packages": [
                        {
                            "specs": [
                                "https://identifiers.org/rrid/RRID:SCR_008249"
                            ],
                            "version": [
                                "1.9.1"
                            ],
                            "package": "qiime"
                        }
                    ],
                    "class": "SoftwareRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_1929",
                    "inputBinding": {
                        "prefix": "--input_fp"
                    },
                    "id": "#qiime-pick_closed_reference_otus.cwl/sequences"
                }
            ],
            "baseCommand": "pick_closed_reference_otus.py",
            "arguments": [
                {
                    "valueFrom": "$(runtime.outdir)",
                    "prefix": "--output_dir"
                },
                "--force"
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "log_*.txt"
                    },
                    "id": "#qiime-pick_closed_reference_otus.cwl/log"
                },
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_3746",
                    "outputBinding": {
                        "glob": "otu_table.biom"
                    },
                    "id": "#qiime-pick_closed_reference_otus.cwl/otu_table"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "97_otus.tree"
                    },
                    "id": "#qiime-pick_closed_reference_otus.cwl/otus_tree"
                },
                {
                    "type": "Directory",
                    "outputBinding": {
                        "glob": "uclust_ref_picked_otus"
                    },
                    "id": "#qiime-pick_closed_reference_otus.cwl/uclust_ref_picked_otus"
                }
            ],
            "id": "#qiime-pick_closed_reference_otus.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute"
        },
        {
            "class": "Workflow",
            "label": "Functional analyis of sequences that match the 16S SSU",
            "requirements": [
                {
                    "class": "SchemaDefRequirement",
                    "types": [
                        {
                            "$import": "#biom-convert-table.yaml/table_type"
                        }
                    ]
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "id": "#main/16S_matches"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#main/convert_new_biom_to_old_biom/result",
                    "id": "#main/biom_json"
                },
                {
                    "type": "File",
                    "outputSource": "#main/create_otu_text_summary/otu_table_summary",
                    "id": "#main/otu_table_summary"
                },
                {
                    "type": "File",
                    "outputSource": "#main/prune_tree/pruned_tree",
                    "id": "#main/tree"
                }
            ],
            "steps": [
                {
                    "run": "#biom-convert.cwl",
                    "in": [
                        {
                            "source": "#main/pick_closed_reference_otus/otu_table",
                            "id": "#main/convert_new_biom_to_classic/biom"
                        },
                        {
                            "default": "taxonomy",
                            "id": "#main/convert_new_biom_to_classic/header_key"
                        },
                        {
                            "default": "OTU table",
                            "id": "#main/convert_new_biom_to_classic/table_type"
                        },
                        {
                            "default": true,
                            "id": "#main/convert_new_biom_to_classic/tsv"
                        }
                    ],
                    "out": [
                        "#main/convert_new_biom_to_classic/result"
                    ],
                    "id": "#main/convert_new_biom_to_classic"
                },
                {
                    "run": "#biom-convert.cwl",
                    "in": [
                        {
                            "source": "#main/pick_closed_reference_otus/otu_table",
                            "id": "#main/convert_new_biom_to_old_biom/biom"
                        },
                        {
                            "default": true,
                            "id": "#main/convert_new_biom_to_old_biom/json"
                        },
                        {
                            "default": "OTU table",
                            "id": "#main/convert_new_biom_to_old_biom/table_type"
                        }
                    ],
                    "out": [
                        "#main/convert_new_biom_to_old_biom/result"
                    ],
                    "id": "#main/convert_new_biom_to_old_biom"
                },
                {
                    "run": "#biom-summarize_table.cwl",
                    "in": [
                        {
                            "source": "#main/pick_closed_reference_otus/otu_table",
                            "id": "#main/create_otu_text_summary/biom"
                        }
                    ],
                    "out": [
                        "#main/create_otu_text_summary/otu_table_summary"
                    ],
                    "id": "#main/create_otu_text_summary"
                },
                {
                    "run": "#extract_observations.cwl",
                    "in": [
                        {
                            "source": "#main/convert_new_biom_to_classic/result",
                            "id": "#main/extract_observations/tsv_otu_table"
                        }
                    ],
                    "out": [
                        "#main/extract_observations/observations"
                    ],
                    "id": "#main/extract_observations"
                },
                {
                    "run": "#qiime-pick_closed_reference_otus.cwl",
                    "in": [
                        {
                            "source": "#main/16S_matches",
                            "id": "#main/pick_closed_reference_otus/sequences"
                        }
                    ],
                    "out": [
                        "#main/pick_closed_reference_otus/otu_table",
                        "#main/pick_closed_reference_otus/otus_tree"
                    ],
                    "id": "#main/pick_closed_reference_otus"
                },
                {
                    "run": "#qiime-filter_tree.cwl",
                    "in": [
                        {
                            "source": "#main/extract_observations/observations",
                            "id": "#main/prune_tree/tips_or_seqids_to_retain"
                        },
                        {
                            "source": "#main/pick_closed_reference_otus/otus_tree",
                            "id": "#main/prune_tree/tree"
                        }
                    ],
                    "out": [
                        "#main/prune_tree/pruned_tree"
                    ],
                    "id": "#main/prune_tree"
                }
            ],
            "id": "#main",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute"
        }
    ],
    "cwlVersion": "v1.0",
    "$schemas": [
        "https://schema.org/docs/schema_org_rdfa.html",
        "http://edamontology.org/EDAM_1.16.owl"
    ],
    "$namespaces": {
        "edam": "http://edamontology.org/",
        "s": "http://schema.org/"
    }
}
